@@ -1,9 +1,10 @@
-
+from .connector import PostgresConnector
 from .api_connector import PostgresAPIConnector
 from .jdbc_connector import PostgresJDBCConnector
 from .odbc_connector import PostgresODBCConnector
 
 __all__ = [
+    "PostgresConnector",
     "PostgresAPIConnector",
     "PostgresJDBCConnector",
     "PostgresODBCConnector"
